import { NextResponse, NextRequest } from 'next/server'
import { validateToken, decryptToken } from '@/lib/jwt'
import { db } from "@/lib/db"
 
export async function GET(req: NextRequest) {
  try {
    const token = req?.headers.get("authorization")?.split(" ")[1]

    if(token == undefined) {
      return NextResponse.json({"message": "You did not provide a token."},{
        status: 401,
      });
    }
    
    if(!validateToken(token)) {
      return NextResponse.json({"message": "Your token is not valid."},{
        status: 401,
      });
    }

    const tokenData = decryptToken(token)

    const decks = await db.deck.findMany({
      where: {
        utilisateurice_id: tokenData.id
      },
      relationLoadStrategy: "join",
      include: {
        cartes: {
          include: {
            carte: true
          }
        },
        commander: true
      }
    })

    return NextResponse.json({"data": decks, "message": "Deck created !"},{
      status: 200,
    });
  } catch (error) {
    console.log(error)
    return NextResponse.json(
      { error: "Failed, check console" },
      {
        status: 500,
      }
    );
  }
}
