import { NextResponse, NextRequest } from 'next/server'
import { validateToken, decryptToken } from '@/lib/jwt'
import { db } from "@/lib/db"
 
interface orFilterProps {
  id:       string
}

export async function POST(req: NextRequest) {
  try {
    const token = req?.headers.get("authorization")?.split(" ")[1]
    const { bset_name, selected_sets } = await req.json()

    if(token !== undefined) {
      if(validateToken(token)) {
        const tokenData = decryptToken(token)
        if(tokenData.admin == true){

          if(bset_name != undefined && selected_sets != undefined) {
            const bset = await db.bset.create({
              data: {
                name: bset_name,
                sanitized_name: bset_name.replace(/[^a-zA-Z0-9]/gim,"-").toLowerCase()
              }
            })

            const or_filter: orFilterProps[] = []
            selected_sets.forEach((set_id: string) => {
              or_filter.push({ id: set_id })
            })

            await db.set.updateMany({
              where: {
                OR: or_filter 
              },
              data: {
                bset_id: bset.id
              }
            })

            return NextResponse.json({"data": bset.id, "message": "BSet created !"},{
              status: 200,
            });
          }

        } else {
          return NextResponse.json({"message": "You're not admin."},{
            status: 401,
          });
        }
      } else {
        return NextResponse.json({"message": "Your token is not valid."},{
          status: 401,
        });
      }
    } else {
        return NextResponse.json({"message": "You did not provide a token."},{
          status: 401,
        });
      }
  } catch (error) {
    console.log(error)
    return NextResponse.json(
      { error: "Failed, check console" },
      {
        status: 500,
      }
    );
  }
}
